﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Controls.Menus;
using System.Windows.Data;
using Infragistics.Controls.Editors;
using System.Collections.Generic;
using System.Collections;

namespace XamRibbonSample
{
    public class XamComboEditorTool : RibbonTool
    {
        private XamComboEditorToolControl _control;

        public XamComboEditorToolControl Control
        {
            get { return _control; }
            set { _control = value; }
        }

        private void UpdateBindings()
        {
            if (this._control != null)
            {
                this._control.OnApplyTemplate();
            }
        }

        protected override RibbonToolBaseControl ResolveToolControl()
        {
            XamComboEditorToolControl control = new XamComboEditorToolControl(this);
            if (this._control == null)
            {
                this._control = control;
            }
            return control;
        }


        public IEnumerable ItemsSource
        {
            get { return (IEnumerable)GetValue(ItemsSourceProperty); }
            set
            {
                SetValue(ItemsSourceProperty, value);
                this.UpdateBindings();
            }
        }

        public static readonly DependencyProperty ItemsSourceProperty =
            DependencyProperty.Register("ItemsSource", typeof(IEnumerable),
            typeof(XamComboEditorTool), null);


        public String DisplayMemberPath { get; set; }

        public Visibility CheckBoxVisibility { get; set; }

        public bool AllowMultipleSelection { get; set; }

        public double Height { get; set; }

        public double Width { get; set; }

        #region SelectedItem Property

        public object SelectedItem
        {
            get { return GetValue(SelectedItemProperty); }
            set { SetValue(SelectedItemProperty, value); }
        }

        public static readonly DependencyProperty SelectedItemProperty =
            DependencyProperty.Register("SelectedItem", typeof(object),
            typeof(XamComboEditorTool), new PropertyMetadata(new PropertyChangedCallback(OnSelectionChanged)));

        private static void OnSelectionChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            XamComboEditorTool tool = (XamComboEditorTool)d;

            if (tool.SelectionChanged != null)
            {
                List<object> addedItems = new List<object>();
                List<object> removedItems = new List<object>();
                if (e.OldValue != null)
                {
                    removedItems.Add(e.OldValue);
                }
                if (e.NewValue != null)
                {
                    addedItems.Add(e.NewValue);
                }

                tool.SelectionChanged(tool, new SelectionChangedEventArgs(removedItems, addedItems));
            }
        }

        #endregion SelectedItem Property

        public event EventHandler SelectionChanged;


    }

    public class XamComboEditorToolControl : RibbonToolBaseControl, IRibbonControl
    {
        private XamComboEditor _combo;

        public XamComboEditor Combo
        {
            get { return _combo; }
            set { _combo = value; }
        }

        public XamComboEditorToolControl()
        {
            this.DefaultStyleKey = typeof(XamComboEditorToolControl);
        }

        public XamComboEditorToolControl(RibbonToolBase tool)
            : base(tool)
        {
            this.DefaultStyleKey = typeof(XamComboEditorToolControl);
        }

        public override void OnApplyTemplate()
        {
            base.OnApplyTemplate();
            this._combo = GetTemplateChild("XamComboEditor") as XamComboEditor;
            if (this._combo != null)
            {
                this._combo.ItemsSource = ((XamComboEditorTool)this.Tool).ItemsSource;
                Binding b = new Binding("SelectedItem");
                b.Mode = BindingMode.TwoWay;
                b.Source = this.Tool;
                this._combo.SetBinding(XamComboEditor.SelectedItemProperty, b);
                this._combo.DisplayMemberPath = ((XamComboEditorTool)this.Tool).DisplayMemberPath;
                this._combo.CheckBoxVisibility = ((XamComboEditorTool)this.Tool).CheckBoxVisibility;
                this._combo.AllowMultipleSelection = ((XamComboEditorTool)this.Tool).AllowMultipleSelection;
                this._combo.Height = ((XamComboEditorTool)this.Tool).Height;
                this._combo.Width = ((XamComboEditorTool)this.Tool).Width;
            }
        }
    }
}
